rtcritical.clj-ant-tasks


run-ant-taskclj

(run-ant-task & rest)
source

run-ant-tasksclj

(run-ant-tasks & rest)

Takes unlimited number of vectors of xml sexp representing ant tasks, as wanted by clojure.data.xml's #'sexp-as-element. Example: (run-ant-tasks [:echo "hi"] [:touch {:file "/tmp/test.txt"}])

Takes unlimited number of vectors of xml sexp representing ant tasks, as wanted by clojure.data.xml's #'sexp-as-element. Example: (run-ant-tasks [:echo "hi"] [:touch {:file "/tmp/test.txt"}])
sourceraw docstring

target-nameclj

source

cljdoc builds & hosts documentation for Clojure/Script libraries