(run-ant-tasks & rest)Takes unlimited number of vectors of xml sexp representing ant tasks, as wanted by clojure.data.xml's #'sexp-as-element. Example: (run-ant-tasks [:echo "hi"] [:touch {:file "/tmp/test.txt"}])
Takes unlimited number of vectors of xml sexp representing ant tasks, as wanted by clojure.data.xml's #'sexp-as-element. Example: (run-ant-tasks [:echo "hi"] [:touch {:file "/tmp/test.txt"}])
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |